Learn R Programming

hemat (version 1.1.3)

calc_mch: Calculate Mean Corpuscular Hemoglobin (MCH)

Description

Calculates the MCH based on hemoglobin concentration and red blood cell count. MCH measures the average amount of hemoglobin per red blood cell.

Usage

calc_mch(hb, rb)

Value

Numeric value representing the MCH in picograms (pg).

Arguments

hb

Numeric value representing the hemoglobin concentration in g/dL.

rb

Numeric value representing the red blood cell count (millions/ µL).

Examples

Run this code
calc_mch(15, 5)

Run the code above in your browser using DataLab