Learn R Programming

hemat (version 1.1.3)

calc_mcv: Calculate Mean Corpuscular Volume (MCV)

Description

MCV measures the average volume of red blood cells in a blood sample.

Usage

calc_mcv(ht, rb)

Value

Numeric value representing the MCV in femtoliters (fL).

Arguments

ht

Numeric value representing the hematocrit in percentage.

rb

Numeric value representing the red blood cell count (millions/ µL).

Examples

Run this code
calc_mcv(40, 5)

Run the code above in your browser using DataLab