powered by
Calculates the MCH based on hemoglobin concentration and red blood cell count. MCH measures the average amount of hemoglobin per red blood cell.
calc_mch(hb, rb)
Numeric value representing the MCH in picograms (pg).
Numeric value representing the hemoglobin concentration in g/dL.
Numeric value representing the red blood cell count (millions/ µL).
calc_mch(15, 5)
Run the code above in your browser using DataLab