powered by
MCV measures the average volume of red blood cells in a blood sample.
calc_mcv(ht, rb)
Numeric value representing the MCV in femtoliters (fL).
Numeric value representing the hematocrit in percentage.
Numeric value representing the red blood cell count (millions/ µL).
calc_mcv(40, 5)
Run the code above in your browser using DataLab